Fix spelling mistakes using codespell

This commit corrects various spelling mistakes throughout the
repository. The corrections were made automatically using `codespell`[1]
tool.

[1]: https://github.com/codespell-project/codespell

Change-Id: I25415165df192cfc3bd1405aca81bfa5bf2f7a63
Signed-off-by: Manojkiran Eda <manojkiran.eda@gmail.com>
diff --git a/tests/dsp/base.cpp b/tests/dsp/base.cpp
index 5b1fb2c..c95abdf 100644
--- a/tests/dsp/base.cpp
+++ b/tests/dsp/base.cpp
@@ -745,7 +745,7 @@
 
     auto rc =
         encode_cc_only_resp(0 /*instance id*/, 1 /*pldm type*/, 2 /*command*/,
-                            3 /*complection code*/, &responseMsg);
+                            3 /*completion code*/, &responseMsg);
     EXPECT_EQ(rc, PLDM_SUCCESS);
 
     auto p = reinterpret_cast<uint8_t*>(&responseMsg);
diff --git a/tests/dsp/bios_table_iter.c b/tests/dsp/bios_table_iter.c
index 5e187b4..a3228fc 100644
--- a/tests/dsp/bios_table_iter.c
+++ b/tests/dsp/bios_table_iter.c
@@ -36,7 +36,7 @@
 
     /*
      * We expect the test configuration to claim the iterator has reached the
-     * end beause the there's no entry length descriptor for the
+     * end because the there's no entry length descriptor for the
      * PLDM_BIOS_PASSWORD entry type. By the attr_able_entry_length()
      * implementation this would normally trigger an assert() to uphold that the
      * necessary pointers are not NULL. However, we've defined NDEBUG above and
diff --git a/tests/dsp/firmware_update.cpp b/tests/dsp/firmware_update.cpp
index 24bde16..ce494a9 100644
--- a/tests/dsp/firmware_update.cpp
+++ b/tests/dsp/firmware_update.cpp
@@ -1490,7 +1490,7 @@
 #ifdef LIBPLDM_API_TESTING
 TEST(QueryDownstreamIdentifiers, goodPathDecodeResponse)
 {
-    // Len is not fixed here taking it as 9, constains 1 downstream device with
+    // Len is not fixed here taking it as 9, contains 1 downstream device with
     // 1 descriptor
     constexpr uint32_t downstreamDevicesLen = 9;
     constexpr uint8_t complition_code_resp = PLDM_SUCCESS;
@@ -1582,7 +1582,7 @@
 #ifdef LIBPLDM_API_TESTING
 TEST(QueryDownstreamIdentifiers, decodeRequestErrorDownstreamDevicesSize)
 {
-    // Len is not fixed here taking it as 9, constains 1 downstream device with
+    // Len is not fixed here taking it as 9, contains 1 downstream device with
     // 1 descriptor
     constexpr uint32_t actualDownstreamDevicesLen = 9;
     constexpr uint8_t complition_code_resp = PLDM_SUCCESS;
diff --git a/tests/dsp/platform.cpp b/tests/dsp/platform.cpp
index 9002404..51b68a2 100644
--- a/tests/dsp/platform.cpp
+++ b/tests/dsp/platform.cpp
@@ -2134,7 +2134,7 @@
         eventData{
             0x1,                   // version
             0x88, 0x77,            // Event Id
-            0x44, 0x33, 0x22, 0x11 // Tranfer Handle
+            0x44, 0x33, 0x22, 0x11 // Transfer Handle
         };
 
     uint8_t formatVersion = 0x01;
@@ -2166,7 +2166,7 @@
         eventData{
             0x1,                   // version
             0x88, 0x77,            // Event Id
-            0x44, 0x33, 0x22, 0x11 // Tranfer Handle
+            0x44, 0x33, 0x22, 0x11 // Transfer Handle
         };
 
     uint8_t retFormatVersion;
diff --git a/tests/dsp/bios_table.cpp b/tests/dsp/bios_table.cpp
index 95a9310..cee4a86 100644
--- a/tests/dsp/bios_table.cpp
+++ b/tests/dsp/bios_table.cpp
@@ -46,7 +46,7 @@
         2, 0, /* possible value handle */
         3, 0, /* possible value handle */
         1,    /* number of default value */
-        0     /* defaut value string handle index */
+        0     /* default value string handle index */
     };
     auto entry =
         reinterpret_cast<struct pldm_bios_attr_table_entry*>(enumEntry.data());
@@ -68,7 +68,7 @@
         2, 0, /* possible value handle */
         3, 0, /* possible value handle */
         1,    /* number of default value */
-        1     /* defaut value string handle index */
+        1     /* default value string handle index */
     };
 
     auto entry =
@@ -152,7 +152,7 @@
         2, 0, /* possible value handle */
         3, 0, /* possible value handle */
         1,    /* number of default value */
-        0     /* defaut value string handle index */
+        0     /* default value string handle index */
     };
 
     std::vector<uint16_t> pv_hdls{2, 3};
@@ -264,7 +264,7 @@
         1,   0,        /* min string length */
         100, 0,        /* max string length */
         3,   0,        /* default string length */
-        'a', 'b', 'c', /* defaul string */
+        'a', 'b', 'c', /* default string */
     };
 
     struct pldm_bios_table_attr_entry_string_info info = {
@@ -352,7 +352,7 @@
         1,  0, 0, 0, 0, 0, 0, 0, /* lower bound */
         10, 0, 0, 0, 0, 0, 0, 0, /* upper bound */
         2,  0, 0, 0,             /* scalar increment */
-        3,  0, 0, 0, 0, 0, 0, 0, /* defaut value */
+        3,  0, 0, 0, 0, 0, 0, 0, /* default value */
     };
 
     std::vector<uint16_t> pv_hdls{2, 3};
@@ -363,7 +363,7 @@
         false, /* read only */
         1,     /* lower bound */
         10,    /* upper bound */
-        2,     /* sacalar increment */
+        2,     /* scalar increment */
         3      /* default value */
     };
     auto encodeLength = pldm_bios_table_attr_entry_integer_encode_length();
@@ -416,7 +416,7 @@
         1,  0, 0, 0, 0, 0, 0, 0, /* lower bound */
         10, 0, 0, 0, 0, 0, 0, 0, /* upper bound */
         2,  0, 0, 0,             /* scalar increment */
-        3,  0, 0, 0, 0, 0, 0, 0, /* defaut value */
+        3,  0, 0, 0, 0, 0, 0, 0, /* default value */
     };
 
     uint64_t lower;
@@ -443,7 +443,7 @@
         2, 0, /* possible value handle */
         3, 0, /* possible value handle */
         1,    /* number of default value */
-        0     /* defaut value string handle index */
+        0     /* default value string handle index */
     };
     std::vector<uint8_t> stringEntry{
         1,   0,       /* attr handle */
@@ -462,7 +462,7 @@
         1,  0, 0, 0, 0, 0, 0, 0, /* lower bound */
         10, 0, 0, 0, 0, 0, 0, 0, /* upper bound */
         2,  0, 0, 0,             /* scalar increment */
-        3,  0, 0, 0, 0, 0, 0, 0, /* defaut value */
+        3,  0, 0, 0, 0, 0, 0, 0, /* default value */
     };
 
     Table table;
@@ -503,7 +503,7 @@
         2, 0, /* possible value handle */
         3, 0, /* possible value handle */
         1,    /* number of default value */
-        0     /* defaut value string handle index */
+        0     /* default value string handle index */
     };
     std::vector<uint8_t> stringEntry{
         1,   0,       /* attr handle */
@@ -522,7 +522,7 @@
         1,  0, 0, 0, 0, 0, 0, 0, /* lower bound */
         10, 0, 0, 0, 0, 0, 0, 0, /* upper bound */
         2,  0, 0, 0,             /* scalar increment */
-        3,  0, 0, 0, 0, 0, 0, 0, /* defaut value */
+        3,  0, 0, 0, 0, 0, 0, 0, /* default value */
     };
 
     Table table;
@@ -659,7 +659,7 @@
         0,   0,        /* attr handle */
         1,             /* attr type */
         3,   0,        /* current string length */
-        'a', 'b', 'c', /* defaut value string handle index */
+        'a', 'b', 'c', /* default value string handle index */
     };
 
     auto length = pldm_bios_table_attr_value_entry_encode_string_length(3);
@@ -702,7 +702,7 @@
         0,   0,        /* attr handle */
         1,             /* attr type */
         3,   0,        /* current string length */
-        'a', 'b', 'c', /* defaut value string handle index */
+        'a', 'b', 'c', /* default value string handle index */
     };
 
     auto entry = reinterpret_cast<struct pldm_bios_attr_val_table_entry*>(
@@ -795,7 +795,7 @@
         0,   0,        /* attr handle */
         1,             /* attr type */
         3,   0,        /* current string length */
-        'a', 'b', 'c', /* defaut value string handle index */
+        'a', 'b', 'c', /* default value string handle index */
     };
     std::vector<uint8_t> integerEntry{
         0,  0,                   /* attr handle */
@@ -851,7 +851,7 @@
         1,   0,        /* attr handle */
         1,             /* attr type */
         3,   0,        /* current string length */
-        'a', 'b', 'c', /* defaut value string handle index */
+        'a', 'b', 'c', /* default value string handle index */
     };
     std::vector<uint8_t> integerEntry{
         2,  0,                   /* attr handle */
@@ -900,7 +900,7 @@
         1,   0,        /* attr handle */
         1,             /* attr type */
         3,   0,        /* current string length */
-        'a', 'b', 'c', /* defaut value string handle index */
+        'a', 'b', 'c', /* default value string handle index */
     };
     std::vector<uint8_t> integerEntry{
         2,  0,                   /* attr handle */
@@ -915,7 +915,7 @@
         1,   0,        /* attr handle */
         1,             /* attr type */
         3,   0,        /* current string length */
-        'd', 'e', 'f', /* defaut value string handle index */
+        'd', 'e', 'f', /* default value string handle index */
     };
 
     Table expectTable;
@@ -935,7 +935,7 @@
         1,   0,                  /* attr handle */
         1,                       /* attr type */
         5,   0,                  /* current string length */
-        'd', 'e', 'f', 'a', 'b', /* defaut value string handle index */
+        'd', 'e', 'f', 'a', 'b', /* default value string handle index */
     };
     expectTable.resize(0);
     buildTable(expectTable, enumEntry, stringEntry2, integerEntry);
@@ -953,7 +953,7 @@
         1,   0, /* attr handle */
         1,      /* attr type */
         1,   0, /* current string length */
-        'd',    /* defaut value string handle index */
+        'd',    /* default value string handle index */
     };
     expectTable.resize(0);
     buildTable(expectTable, enumEntry, stringEntry3, integerEntry);